mutation CreateInventories {
    alltypes: _createInventory(input: {
        inventoryName: "AllTypes"
        properties: [
            { dataType: BOOLEAN propertyName: "Wahrheitstyp" isRequired: false isArray: false isUnique: false },
            { dataType: DATE propertyName: "Datum" isRequired: false isArray: false isUnique: false },
            { dataType: DATE_TIME propertyName: "DateTime" isRequired: false isArray: false isUnique: false },
            { dataType: DATE_TIME_OFFSET propertyName: "DateTimeOffset" isRequired: false isArray: false isUnique: false },
            { dataType: DECIMAL propertyName: "Dezimal" isRequired: false isArray: false isUnique: false },
            { dataType: FILE propertyName: "Datei" file: { maxLength: "1024" } isRequired: false isArray: false isUnique: false },
            { dataType: GUID propertyName: "Guid" isRequired: false isArray: false isUnique: false },
            { dataType: INT propertyName: "Integer" isRequired: false isArray: false isUnique: false },
            { dataType: LONG propertyName: "Land" isRequired: false isArray: false isUnique: false },
            { dataType: STRING propertyName: "Zeichenkette" string: {isCaseSensitive: false maxLength: "10"} isRequired: false isArray: false isUnique: false },
            { dataType: TIME propertyName: "Uhrzeit" isRequired: false isArray: false isUnique: false },
            { dataType: TIME_SERIES propertyName: "Zeitreihe" timeSeries: { allowSpecificsPerInstance: false enableAudit: false enableQuotation: false interval: {multiplier: "15" timeUnit: MINUTE} unit: "W" valueAlignment: LEFT valueAvailability: AT_INTERVAL_BEGIN} isRequired: false isArray: false isUnique: false },
        ]
    }) {
        name existed
    }
    _createNamespace(input: {
        namespaceName: "TestNamespace"
        ifExists: IGNORE
    }) {
        name existed
    }
    namespaced: _createInventory(input: {
        namespaceName: "TestNamespace"
        inventoryName: "TestInventory"
        properties: [
            { dataType: STRING propertyName: "Zeichenkette" string: {isCaseSensitive: false maxLength: "10"} isRequired: false isArray: false isUnique: false },
        ]
    }) {
        name existed
    }
}